@@ -19,6 +19,6 @@
 
 LIBDIR = r'/usr/local/lib'
 DATADIR = r'/usr/local/share'
-BUILDDIR = r'/usr/obj/ports/gst-devtools-1.26.8/build-sparc64'
-SRCDIR = r'/usr/obj/ports/gst-devtools-1.26.8/gst-devtools-1.26.8'
+BUILDDIR = r'/usr/obj/ports/gst-devtools-1.26.9/build-powerpc64'
+SRCDIR = r'/usr/obj/ports/gst-devtools-1.26.9/gst-devtools-1.26.9'
 GST_VALIDATE_TESTSUITE_VERSION = '1.26'
